packer {
  required_plugins {
    amazon = {
      version = ">= 1.2.8"
      source  = "github.com/hashicorp/amazon"
    }
  }
}

variable "agent_version" {
  type = string
  default = "latest"
}

variable "jmeter_version" {
  type = string
  default = "latest"
}

variable "aws_instance_type" {
  type = string
  default = "t2.large"
}
variable "ami_name" {
  type = string
  default = "octoperf-machine"
}

variable "aws_access_key" {
  type = string
}

variable "aws_secret_key" {
  type = string
}

variable "vpc_id_eu-west-1" {
  type = string
}

variable "subnet_id_eu-west-1" {
  type = string
}

variable "ami_eu-west-1" {
  type = string
}

locals { timestamp = regex_replace(timestamp(), "[- TZ:]", "") }

source "amazon-ebs" "amazon-eu-west-1" {
  access_key    = "${var.aws_access_key}"
  ami_name      = "${var.ami_name}-${local.timestamp}"
  ami_regions   = [
    "us-east-1",
    "us-east-2",
    "us-west-1",
    "us-west-2",
    "af-south-1",
    "ap-east-1",
    "ap-northeast-1",
    "ap-northeast-2",
    "ap-northeast-3",
    "ap-south-1",
    "ap-southeast-1",
    "ap-southeast-2",
    "ap-southeast-3",
    "ca-central-1",
    "eu-central-1",
    "eu-central-2",
    "eu-south-1",
    "eu-west-2",
    "eu-west-3",
    "eu-north-1",
    "me-south-1",
    "sa-east-1",
    "eu-south-2",
    "me-central-1",
    "il-central-1",
    "ap-southeast-4",
    "ap-south-2"
  ]
  instance_type = "${var.aws_instance_type}"
  launch_block_device_mappings {
    delete_on_termination = true
    device_name           = "/dev/sda1"
    volume_size           = 16
    volume_type           = "gp2"
  }
  region       = "eu-west-1"
  secret_key   = "${var.aws_secret_key}"
  source_ami   = "${var.ami_eu-west-1}"
  ssh_username = "ubuntu"
  subnet_id    = "${var.subnet_id_eu-west-1}"
  vpc_id       = "${var.vpc_id_eu-west-1}"
}

build {
  sources = ["source.amazon-ebs.amazon-eu-west-1"]

  provisioner "shell" {
    inline = [
      "wget -qO- https://get.docker.com/ | sh", "sudo usermod -aG docker ubuntu",
      "sudo docker pull octoperf/docker-agent:${var.agent_version}",
      "sudo docker pull octoperf/jmeter-standard:${var.jmeter_version}",
      "sudo docker pull octoperf/jmeter-webdriver:${var.jmeter_version}",
      "sudo docker pull octoperf/jmeter-playwright:${var.jmeter_version}"
    ]
  }

  post-processor "manifest" {
    output     = "amazon-manifest.json"
    strip_path = true
  }
}

